@@ -1,3 +1,3 @@
 from RocketCasing import RocketCasing
 
-RocketCasing.casing()
\ No newline at end of file
+RocketCasing.case()
